Struct cranelift_bforest::Set [−][src]
pub struct Set<K> where
K: Copy, { /* fields omitted */ }Expand description
B-tree representing an ordered set of Ks using C for comparing elements.
This is not a general-purpose replacement for BTreeSet. See the module
documentation for more information about design tradeoffs.
Sets can be cloned, but that operation should only be used as part of cloning the whole forest they belong to. Cloning a set does not allocate new memory for the clone. It creates an alias of the same memory.
Implementations
Does the set contain key?.
Try to insert key into the set.
If the set did not contain key, insert it and return true.
If key is already present, don’t change the set and return false.
Remove key from the set and return true.
If key was not present in the set, return false.
Retains only the elements specified by the predicate.
Remove all elements where the predicate returns false.
Create a cursor for navigating this set. The cursor is initially positioned off the end of the set.